==> apache-cxf-3.4.5-src.tar.gz: apache-cxf-3.4.5-src/testutils/src/main/java/org/apache/hello_world/GreeterImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.hello_world;

import javax.jws.WebService;

import org.apache.hello_world.messages.PingMeFault;

@WebService(serviceName = "SOAPService",
            portName = "SoapPort",
            endpointInterface = "org.apache.hello_world.Greeter",
            targetNamespace = "http://apache.org/hello_world/services",
            wsdlLocation = "testutils/others/hello_world_services_catalog.wsdl")
public class GreeterImpl implements Greeter {

    public GreeterImpl() {
    }

    public String greetMe(String requestType) {
        return "Hello " + requestType;
    }

    /** {@inheritDoc}*/
    public void pingMe() throws PingMeFault {
    }

    /** {@inheritDoc}*/
    public String sayHi() {
        return "Hi!";
    }

}

==> apache-cxf-4.0.7-src.tar.gz: apache-cxf-4.0.7-src/testutils/src/main/java/org/apache/hello_world/GreeterImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.hello_world;

import jakarta.jws.WebService;
import org.apache.hello_world.messages.PingMeFault;

@WebService(serviceName = "SOAPService",
            portName = "SoapPort",
            endpointInterface = "org.apache.hello_world.Greeter",
            targetNamespace = "http://apache.org/hello_world/services",
            wsdlLocation = "testutils/others/hello_world_services_catalog.wsdl")
public class GreeterImpl implements Greeter {

    public GreeterImpl() {
    }

    public String greetMe(String requestType) {
        return "Hello " + requestType;
    }

    /** {@inheritDoc}*/
    public void pingMe() throws PingMeFault {
    }

    /** {@inheritDoc}*/
    public String sayHi() {
        return "Hi!";
    }

}
